@@ -1,4 +1,6 @@
+import sys
+
 from ._codespell import _script_main
 
 if __name__ == "__main__":
-    _script_main()
+    sys.exit(_script_main())
